#adjust this to the folder that contains data files
setwd("/Users/ding/Documents/presentation training/Dataset files (22.6 kB)/data")

# transfer all the output to a file.
sink("output_PresentationTraining_analysisResults", split = "TRUE")
R.version.string
sessionInfo()
# for more information, use R.Version()

cat("\n###############################################################################\n")
cat("\n# Analysis for the paper for Annual Review of Cybertherapy And Telemedicine 2019: \n")
cat("\n# 2019 TUDelft\n")
cat("\n# Output file: output_PresentationTraining_analysisResults.txt will be created \n")
cat("\n# Author: Ni Kang, Ding Ding \n")
cat("\n# required datafile from PS training data\n")
cat("\n# - PS training data.csv\n")

####################### Functions #######################
testbetween <-function(sample1,sample2)
{
  # x integer data being tested
  # g group
  
  # convert group into factor:
  #g <- factor(g)
  x<-c(sample1, sample2)
  g<-as.factor(c(rep(1, length(sample1)), rep(2, length(sample2))))
  
  l<-leveneTest(x,g)
  if (l$`Pr(>F)`[1]<.05)
  {
    cat("\nLevene's test shows sign difference between the group variance, therefore  Welch Two Sample t-test conducted\n")
    print(t.test(x~g, na.rm = TRUE,var.equal = FALSE))
  } else
  {
    cat("\nLevene's test shows no sign difference between the group variance, therefore  Two Sample t-test conducted\n")
    print(t.test(x~g, na.rm = TRUE,var.equal = TRUE))
  }
}

print_ezANOVA <- function(m){
  #print output ezANOVA, including effectsize eta, and Greenhouse-Geisser corrected dfs
  print(m)
  
  m$ANOVA$eta <- m$ANOVA$SSn/(m$ANOVA$SSn + m$ANOVA$SSd)
  for (i in 1:length(m$ANOVA$Effect)) 
  { cat(m$ANOVA$Effect[i]," : eta ", m$ANOVA$eta[i]," \n")
  }
  cat("see ges-value for Generalized Eta-Squared) \n\n")
  
  cat("Greenhouse-Geisser corrected Dfs. \n") 
  for (i in 1:length(m$`Sphericity Corrections`$Effect))
  { 
    for (j in 1:length(m$ANOVA$Effect)) {
      if (m$ANOVA$Effect[j] == m$`Sphericity Corrections`$Effect[i]){
        m$`Sphericity Corrections`$DFn_G[i] <- m$ANOVA$DFn[j] * m$`Sphericity Corrections`$GGe[i]
        m$`Sphericity Corrections`$DFd_G[i] <- m$ANOVA$DFd[j] * m$`Sphericity Corrections`$GGe[i]
        cat(m$`Sphericity Corrections`$Effect[i],
            " numerator ", m$`Sphericity Corrections`$DFn_G[i], " , denominator ", m$`Sphericity Corrections`$DFd_G[i], "\n")
        
      }
    }
  }
}

################################# libraries #################################
library(foreign)
library(car)
library(ggplot2)
library(nlme)
library(reshape)
library(lattice)
library(MASS)
library(psych)
library(pwr)
library(ggpubr)
library(dplyr)
library(lsr)
library(outliers)
library(coin)
library(lme4)
library(ez)
library(afex)
library(Hmisc)

PStrainingData<- read.csv("PS training data.csv", header = TRUE, sep=";")

cat("\n#################### refer to 3. Data preparation and analysis  ####################\n")
cat("\n###### Cronbach's alpha for PR and utility questionnaire###### \n")
cat("\n#### Cronbach's alpha for PR\n")
PS_PR<- PStrainingData[1:40,c(2,3,11:13,16:18,21:26)]
PS_PR[] <- lapply(PS_PR, function(x) as.numeric(as.character(x)))
alpha(PS_PR[3:5]) 
alpha(PS_PR[6:8])
alpha(PS_PR[9:11]) 
alpha(PS_PR[12:14])

cat("\n#### Cronbach's alpha for utility questionnaire\n")
PS_Utility<- PStrainingData[1:40,c(2,3,27:38)]
PS_Utility[] <- lapply(PS_Utility, function(x) as.numeric(as.character(x)))
alpha(PS_Utility[c(3,4,5,6,12)])
alpha(PS_Utility[c(7,8,9,10,11,13,14)])


cat("\n#################### refer to 4. Results ####################\n")
cat("\n###### refer to table 1: Descriptive statistics of the measures and results of independent t-tests ###### \n")

cat("\n#### Row 1: PRCS (Personal report of confidence as a speaker) ####\n")
PS_PRCS<- PStrainingData[1:40,c(2,3,7)]
PRCS_VR<-subset(PS_PRCS,cond==1)
PRCS_IM<-subset(PS_PRCS,cond==0)
cat("\n## Mean and Standard deviation of Virtual reality (VR) condition and Imagination (IM) condition\n")
describeBy(PS_PRCS,PS_PRCS$cond)
cat("## Indenpendence T-test and effect size: r\n")
testbetween(PRCS_VR$PRCS,PRCS_IM$PRCS)
cat("## The effect size: r\n")
d_PRCS<-cohensD(PRCS_VR$PRCS,PRCS_IM$PRCS)
d_PRCS/sqrt(d_PRCS^2+4)

cat("#### Row 2: Age ####\n")
PS_Age<- PStrainingData[1:40,c(2,3,4)]
Age_VR<-subset(PS_Age,cond==1)
Age_IM<-subset(PS_Age,cond==0)
cat("## Mean and Standard deviation of Virtual reality (VR) condition and Imagination (IM) condition\n")
describeBy(PS_Age,PS_Age$cond)
# describe(Age_VR)
# describe(Age_IM)
cat("## Indenpendence T-test and effect size: r\n")
testbetween(Age_VR$age,Age_IM$age)
cat("## The effect size: r\n")
d_Age<-cohensD(Age_VR$age,Age_IM$age)
d_Age/sqrt(d_Age^2+4)

cat("#### Row 3: Self-efficacy ####\n")
PS_SE<- PStrainingData[1:40,c(2,3,9)]
SE_VR<-subset(PS_SE,cond==1)
SE_IM<-subset(PS_SE,cond==0)
cat("## Mean and Standard deviation of Virtual reality (VR) condition and Imagination (IM) condition\n")
describeBy(PS_SE,PS_SE$cond)
# describe(SE_VR)
# describe(SE_IM)
cat("## Indenpendence T-test and effect size: r\n")
testbetween(SE_VR$confidence_S1_pre,SE_IM$confidence_S1_pre)
#cohensD(SE_VR$confidence_S1_pre,SE_IM$confidence_S1_pre)
cat("## The effect size: r\n")
d_SE<-cohensD(SE_VR$confidence_S1_pre,SE_IM$confidence_S1_pre)
d_SE/sqrt(d_SE^2+4)

cat("#### Row 4: Presence response (PR) ####\n")
PS_PR_Formalized<-data.frame(PS_PR$ID,PS_PR$cond,rowMeans(PS_PR[3:5]),rowMeans(PS_PR[6:8]),rowMeans(PS_PR[9:11]),rowMeans(PS_PR[12:14]))
colnames(PS_PR_Formalized) <- c("ID","cond","Session1","Session2","Session3","Session4")
PR_VR<-subset(PS_PR_Formalized,cond==1)
PR_IM<-subset(PS_PR_Formalized,cond==0)
cat("## Mean and Standard deviation of Virtual reality (VR) condition and Imagination (IM) condition\n")
describeBy(PS_PR_Formalized,PS_PR_Formalized$cond)
# describe(PR_VR)
# describe(PR_IM)
cat("## Indenpendence t-test and effect size: r")
cat("## Session 1")
testbetween(PR_VR$Session1,PR_IM$Session1)
cat("## The effect size: r\n")
d_S1<-cohensD(PR_VR$Session1,PR_IM$Session1)
d_S1/sqrt(d_S1^2+4)
cat("## Session 2")
testbetween(PR_VR$Session2,PR_IM$Session2)
cat("## The effect size: r\n")
d_S2<-cohensD(PR_VR$Session2,PR_IM$Session2)
d_S2/sqrt(d_S2^2+4)
cat("## Session 3")
testbetween(PR_VR$Session3,PR_IM$Session3)
cat("## The effect size: r\n")
d_S3<-cohensD(PR_VR$Session3,PR_IM$Session3)
d_S3/sqrt(d_S3^2+4)
cat("## Closing presentation")
testbetween(PR_VR$Session4,PR_IM$Session4)
cat("## The effect size: r\n")
d_S4<-cohensD(PR_VR$Session4,PR_IM$Session4)
d_S4/sqrt(d_S4^2+4)

cat("#### Row 5: Utility ####\n")
PS_Utility_Formalized<-data.frame(PS_Utility$ID,PS_Utility$cond,rowMeans(PS_Utility[c(3,4,5,6,12)]),rowMeans(PS_Utility[c(7,8,9,10,11,13,14)]))
colnames(PS_Utility_Formalized) <- c("ID","cond","Procress_Related","Outcome_Related")
Utility_VR<-subset(PS_Utility_Formalized,cond=="1")
Utility_IM<-subset(PS_Utility_Formalized,cond=="0")
cat("## Mean and Standard deviation of Virtual reality (VR) condition and Imagination (IM) condition\n")
describeBy(PS_Utility_Formalized,PS_Utility_Formalized$cond)
# describe(Utility_VR)
# describe(Utility_IM)
cat("## Indenpendence T-test and effect size: r\n")
cat("## Process_Related\n")
testbetween(Utility_VR$Procress_Related,Utility_IM$Procress_Related)
cat("## The effect size: r\n")
d_UtilityProcress<-cohensD(Utility_VR$Procress_Related,Utility_IM$Procress_Related)
d_UtilityProcress/sqrt(d_UtilityProcress^2+4)
cat("## Process_Related\n")
testbetween(Utility_VR$Outcome_Related,Utility_IM$Outcome_Related)
cat("## The effect size: r\n")
d_UtilityOutcome<-cohensD(Utility_VR$Outcome_Related,Utility_IM$Outcome_Related)
d_UtilityOutcome/sqrt(d_UtilityOutcome^2+4)

cat("#### Row 6: Length of answers(LA) ####\n")
PS_LA<- PStrainingData[1:40,c(2,3,50,52,54,56)]
colnames(PS_LA) <- c("ID","cond","Session1","Session2","Session3","Session4")
PS_LA$Session1 <- gsub(",",".",PS_LA$Session1,fixed=TRUE)
PS_LA$Session2 <- gsub(",",".",PS_LA$Session2,fixed=TRUE)
PS_LA$Session3 <- gsub(",",".",PS_LA$Session3,fixed=TRUE)
PS_LA$Session4 <- gsub(",",".",PS_LA$Session4,fixed=TRUE)
PS_LA[] <- lapply(PS_LA, function(x) as.numeric(as.character(x)))
PS_LA_Filtered<- PS_LA[complete.cases(PS_LA), ]
PS_LA_Filtered$Total<-rowSums(PS_LA_Filtered[3:6])
LA_VR<-subset(PS_LA_Filtered,cond==1)
LA_IM<-subset(PS_LA_Filtered,cond==0)
cat("## Mean and Standard deviation of Virtual reality (VR) condition and Imagination (IM) condition\n")
describeBy(PS_LA_Filtered,PS_LA_Filtered$cond)
# describe(LA_VR)
# describe(LA_IM)
cat("## Indenpendence T-test and effect size: r")
testbetween(LA_VR$Total,LA_IM$Total)
#cohensD(LA_VR$Total,LA_IM$Total)
cat("## The effect size: r\n")
d_LA<-cohensD(LA_VR$Total,LA_IM$Total)
d_LA/sqrt(d_LA^2+4)

cat("\n#################### refer to 4 Results ####################\n")
cat("\n###### refer to Paragraph 2: Presence response (PR) ###### \n")
PR_Formalized<-melt(PS_PR_Formalized, id=(c("ID","cond")))
colnames(PR_Formalized, do.NULL = TRUE)
colnames(PR_Formalized) <- c("ID","cond","Session", "Score")
PR_Formalized$ID<-factor(PR_Formalized$ID)
PR_Formalized$cond<-factor(PR_Formalized$cond)
ezANOVA(data=PR_Formalized,dv=Score,wid=ID,within=Session,between=cond)
#ezANOVA(data=PR_Formalized,dv=Score,wid=ID,within=Session,between=cond,detailed = TRUE)
pairwise.t.test(PR_Formalized$Score,PR_Formalized$Session, paired = TRUE, p.adjust.method = "none")

cat("\n###### refer to Paragraph 3: Analysis for heart rate (HR), subjective unit of discomfort (SUD) and length of answers (LA)###### \n")
PS_HR<- PStrainingData[1:40,c(2,3,41,43,45,47)]
colnames(PS_HR) <- c("ID","cond","Session1","Session2","Session3","Session4")
PS_HR$Session1 <- gsub(",",".",PS_HR$Session1,fixed=TRUE)
PS_HR$Session2 <- gsub(",",".",PS_HR$Session2,fixed=TRUE)
PS_HR$Session3 <- gsub(",",".",PS_HR$Session3,fixed=TRUE)
PS_HR$Session4 <- gsub(",",".",PS_HR$Session4,fixed=TRUE)
PS_HR[] <- lapply(PS_HR, function(x) as.numeric(as.character(x)))

PS_SUD<- PStrainingData[1:40,c(2,3,42,44,46,48)]
colnames(PS_SUD) <- c("ID","cond","Session1","Session2","Session3","Session4")
PS_SUD$Session1 <- gsub(",",".",PS_SUD$Session1,fixed=TRUE)
PS_SUD$Session2 <- gsub(",",".",PS_SUD$Session2,fixed=TRUE)
PS_SUD$Session3 <- gsub(",",".",PS_SUD$Session3,fixed=TRUE)
PS_SUD$Session4 <- gsub(",",".",PS_SUD$Session4,fixed=TRUE)
PS_SUD[] <- lapply(PS_SUD, function(x) as.numeric(as.character(x)))

cat("\n## Heart rate (HR)\n")
HR_Formalized<-melt(PS_HR, id=(c("ID","cond")))
HR_Formalized$ID<-factor(HR_Formalized$ID)
HR_Formalized$cond<-factor(HR_Formalized$cond)
colnames(HR_Formalized, do.NULL = TRUE)
colnames(HR_Formalized) <- c("ID","cond","Session", "Score")
#ezANOVA(data=HR_Formalized,dv=Score,wid=ID,within=Session,between=cond)
Sudmodel_HR<-ezANOVA(data=HR_Formalized,dv=Score,wid=ID,within=Session,between=cond,detailed = TRUE, type =3)
print_ezANOVA(Sudmodel_HR)

cat("\n## Subjective unit of discomfort (SUD)\n")
SUD_Formalized<-melt(PS_SUD, id=(c("ID","cond")))
SUD_Formalized$ID<-factor(SUD_Formalized$ID)
SUD_Formalized$cond<-factor(SUD_Formalized$cond)
colnames(SUD_Formalized, do.NULL = TRUE)
colnames(SUD_Formalized) <- c("ID","cond","Session", "Score")
#ezANOVA(data=SUD_Formalized,dv=Score,wid=ID,within=Session,between=cond)
Sudmodel_SUD<-ezANOVA(data=SUD_Formalized,dv=Score,wid=ID,within=Session,between=cond,detailed = TRUE, type =3)
print_ezANOVA(Sudmodel_SUD)

cat("\n## Pair t-test\n")
cat("\n## 1. Heart rate (HR)\n")
pairwise.t.test(HR_Formalized$Score,HR_Formalized$Session, paired = TRUE, p.adjust.method = "none")
cat("\n## 2. Subjective unit of discomfort (SUD)\n")
pairwise.t.test(SUD_Formalized$Score,SUD_Formalized$Session, paired = TRUE, p.adjust.method = "none")
cat("\n## Comparing with 2.5 for SUD\n")
t.test(SUD_Formalized$Score,mu=2.5)

cat("\n## Length of answers (LA)\n")
LA_Formalized<-melt(PS_LA_Filtered[,c(1,2,3:6)], id=(c("ID","cond")))
LA_Formalized$ID<-factor(LA_Formalized$ID)
LA_Formalized$cond<-factor(LA_Formalized$cond)
colnames(LA_Formalized, do.NULL = TRUE)
colnames(LA_Formalized) <- c("ID","cond","Session", "Score")
ezANOVA(data=LA_Formalized,dv=Score,wid=ID,within=Session,between=cond)

cat("\n###### refer to Paragraph 4: Analysis for Utility###### \n")
cat("\n## MANOVA was conducted\n")
Utility_Formalized<-melt(PS_Utility_Formalized, id=(c("ID","cond")))
Utility_Formalized$ID<-factor(Utility_Formalized$ID)
Utility_Formalized$cond<-factor(Utility_Formalized$cond)
colnames(Utility_Formalized, do.NULL = TRUE)
colnames(Utility_Formalized) <- c("ID","cond","Type", "Score")
outcome<-cbind(PS_Utility_Formalized$Procress_Related,PS_Utility_Formalized$Outcome_Related)
ocdmodel<-manova(outcome~cond,data=PS_Utility_Formalized,na.action=na.exclude)
summary(ocdmodel)

cat("\n## univarite ANOVA\n")
cat("\n## Process-related utility\n")
Utility_Procress_Related<-subset(Utility_Formalized, Utility_Formalized$Type=="Procress_Related")
ezANOVA(Utility_Procress_Related,dv=Score,wid=ID,between=cond)
cat("\n## Outcome-related utility\n")
Utility_Outcome_Related<-subset(Utility_Formalized, Utility_Formalized$Type=="Outcome_Related")
ezANOVA(Utility_Outcome_Related,dv=Score,wid=ID,between=cond)

cat("\n###### refer to Paragraph 5: Analysis for self-efficacy###### \n")
PS_SE_ALL<- PStrainingData[1:40,c(2,3,7,8,9,10,14,15,19,20,39,40)]
PS_SE_ALL[] <- lapply(PS_SE_ALL, function(x) as.numeric(as.character(x)))
colnames(PS_SE_ALL) <- c("ID","cond","PRCS","Before","S1_Pre","S1_Post","S2_Pre","S2_Post","S3_Pre","S3_Post","S4_Pre","S4_Post")

#cor(PS_SE_ALL$PRCS, PS_SE_ALL[sapply(PS_SE_ALL, is.numeric)])
#cor(PS_SE_ALL$Before, PS_SE_ALL[sapply(PS_SE_ALL, is.numeric)])
cor_PRCS <- rcorr(as.matrix(PS_SE_ALL), type="pearson")
cat("\n## The correlation check\n")
cor_PRCS$P
#cor_PRCS$r
cat("\n## The self-efficacy measured before the course is correlated with the self-efficacy measured later, therefore the self-efficacy measured before the course could be included as a covariate \n")
cat("\n## The PRCS is not correlated with the self-efficacy measured later, therefore PRCS could not be included as a covariate \n")

SE_Formalized<-melt(PS_SE_ALL, id=(c("ID","cond","PRCS","Before")))
SE_Formalized$Session[SE_Formalized$variable=="S1_Pre"]<-"S1"
SE_Formalized$Time[SE_Formalized$variable=="S1_Pre"]<-"Pre"
SE_Formalized$Session[SE_Formalized$variable=="S1_Post"]<-"S1"
SE_Formalized$Time[SE_Formalized$variable=="S1_Post"]<-"Post"
SE_Formalized$Session[SE_Formalized$variable=="S2_Pre"]<-"S2"
SE_Formalized$Time[SE_Formalized$variable=="S2_Pre"]<-"Pre"
SE_Formalized$Session[SE_Formalized$variable=="S2_Post"]<-"S2"
SE_Formalized$Time[SE_Formalized$variable=="S2_Post"]<-"Post"
SE_Formalized$Session[SE_Formalized$variable=="S3_Pre"]<-"S3"
SE_Formalized$Time[SE_Formalized$variable=="S3_Pre"]<-"Pre"
SE_Formalized$Session[SE_Formalized$variable=="S3_Post"]<-"S3"
SE_Formalized$Time[SE_Formalized$variable=="S3_Post"]<-"Post"
SE_Formalized$Session[SE_Formalized$variable=="S4_Pre"]<-"S4"
SE_Formalized$Time[SE_Formalized$variable=="S4_Pre"]<-"Pre"
SE_Formalized$Session[SE_Formalized$variable=="S4_Post"]<-"S4"
SE_Formalized$Time[SE_Formalized$variable=="S4_Post"]<-"Post"

SE_Final<-SE_Formalized[,c(1,2,3,4,6:8)]
colnames(SE_Final, do.NULL = TRUE)
colnames(SE_Final) <- c("ID","cond","PRCS","Before","Score","Session","Time")
SE_Final$Score<- as.numeric(as.character(SE_Final$Score))
SE_Final$Before<- as.numeric(as.character(SE_Final$Before))

SE_Final$ID<-factor(SE_Final$ID)
SE_Final$cond<-factor(SE_Final$cond)
SE_Final$Session<-factor(SE_Final$Session)
SE_Final$Time<-factor(SE_Final$Time)

cat("\n## Note*: In Ni's PhD thesis, she took both self-efficacy measured before the start of the course and PRCS as the covariates, however according to our above correlation check, PRCS should not be included as a covariate. Therefore the report on the results of self-efficacy in our paper will be different from Ni's thesis. \n")
# model_SE<-aov_ez("ID", "Score", SE_Final, within=c("Session","Time"),between= c("cond"), covariate= c("PRCS","Before"),factorize = FALSE)
# anova(model_SE)

model_SE<-aov_ez("ID", "Score", SE_Final, within=c("Session","Time"),between= c("cond"), covariate= c("Before"),factorize = FALSE)
anova(model_SE)

######### stop redireting output.
sink()
cat("\nOutput of the analysis can be found back in file output_PresentationTraining_analysisResults.txt")